@@ -22,20 +22,20 @@ class Yaspi:
             cmd: str,
             prep: str,
             recipe: str,
-            gen_script_dir: str,
-            log_dir: str,
-            partition: str,
+            gen_script_dir: Path,
+            log_dir: Path,
+            partition: NoneTypeOr[str],
             job_array_size: int,
-            cpus_per_task: int,
-            gpus_per_task: int,
+            cpus_per_task: NoneTypeOr[int],
+            gpus_per_task: NoneTypeOr[int],
             refresh_logs: bool,
             exclude: str,
             use_custom_ray_tmp_dir: bool,
             ssh_forward: str,
-            time_limit: str,
+            time_limit: NoneTypeOr[str],
             throttle_array: int,
             mem: str,
-            constraint_str: str,
+            constraint_str: NoneTypeOr[str],
             custom_directives: str = "",
             template_dir: Path = Path(__file__).parent / "templates",
             job_queue: NoneTypeOr[str] = None,
@@ -58,7 +58,7 @@ class Yaspi:
         self.gpus_per_task = gpus_per_task
         self.constraint_str = constraint_str
         self.throttle_array = throttle_array
-        self.gen_script_dir = Path(gen_script_dir)
+        self.gen_script_dir = gen_script_dir
         self.job_array_size = job_array_size
         self.use_custom_ray_tmp_dir = use_custom_ray_tmp_dir
         self.custom_directives = custom_directives
@@ -127,11 +127,7 @@ class Yaspi:
                     "env_setup": self.env_setup,
                 },
             }
-            if self.gpus_per_task:
-                resource_str = f"#SBATCH --gres=gpu:{self.gpus_per_task}"
-            if self.constraint_str:
-                resource_str = f"{resource_str}\n{self.constraint_str}"
-                rules["sbatch"]["sbatch_resources"] = resource_str
+            self._add_batch_resources(rules)
         elif self.recipe in {"cpu-proc", "gpu-proc"}:
             if self.env_setup is None:
                 # TODO(Samuel): configure this more sensibly
@@ -167,16 +163,11 @@ class Yaspi:
                     "time_limit": self.time_limit,
                     "cpus_per_task": self.cpus_per_task,
                     "exclude_nodes": f"#SBATCH --exclude={self.exclude}",
-                    "sbatch_resources": "",
                     "custom_directives": self.custom_directives,
+                    "sbatch_resources": None,
                 },
             }
-            resource_strs = []
-            if self.constraint_str:
-                resource_strs.append(f"#SBATCH --constraint={self.constraint_str}")
-            if self.gpus_per_task and self.recipe == "gpu-proc":
-                resource_strs.append(f"#SBATCH --gres=gpu:{self.gpus_per_task}")
-            rules["sbatch"]["sbatch_resources"] = "\n".join(resource_strs)
+            self._add_batch_resources(rules, self.recipe == "gpu-proc")
         else:
             raise ValueError(f"template: {self.recipe} unrecognised")
 
@@ -194,6 +185,14 @@ class Yaspi:
                 f.write(gen)
             dest_path.chmod(0o755)
 
+    def _add_batch_resources(self, rules, allow_gpu=True):
+        resource_strs = []
+        if self.constraint_str:
+            resource_strs.append(f"#SBATCH --constraint={self.constraint_str}")
+        if self.gpus_per_task and allow_gpu:
+            resource_strs.append(f"#SBATCH --gres=gpu:{self.gpus_per_task}")
+        rules["sbatch"]["sbatch_resources"] = "\n".join(resource_strs)
+
     def get_log_paths(self):
         watched_logs = []
         for idx in range(self.job_array_size):
@@ -222,19 +221,17 @@ class Yaspi:
         if watch:
             watched_logs = self.get_log_paths()
         submission_cmd = f"bash {self.gen_scripts['master']}"
-        print(f"Submitting job with wrapper: {submission_cmd}")
+        print(f"Submitting job with command: {submission_cmd}")
         print(f"using command:\n{self.cmd}")
-        proc = subprocess.run(submission_cmd.split(), check=True, capture_output=True)
-        job_id = proc.stdout.decode("utf-8").rstrip()
-
-        assert proc.returncode == 0, "Submission failed!"
+        out = subprocess.check_output(submission_cmd.split())
+        job_id = out.decode("utf-8").rstrip()
 
         def halting_condition():
             job_state = f"scontrol show job {job_id}"
-            proc = subprocess.run(job_state.split(), check=True, capture_output=True)
+            out = subprocess.check_output(job_state.split())
             regex = "JobState=[A-Z]+"
             completed = True
-            for match in re.finditer(regex, proc.stdout.decode("utf-8").rstrip()):
+            for match in re.finditer(regex, out.decode("utf-8").rstrip()):
                 status = match.group().replace("JobState=", "")
                 if status != "COMPLETED":
                     return False
@@ -277,15 +274,30 @@ class Yaspi:
         generated = []
         with open(template_path, "r") as f:
             template = f.read().splitlines()
+
+        # A template key use to denote sbatch directives that can be removed
+        # if no value is specified
+        OR_DELETE_LINE = "|ordeleteline"
+
         for row in template:
+            skip_row = False
             edits = []
             regex = r"\{\{(.*?)\}\}"
             for match in re.finditer(regex, row):
                 groups = match.groups()
                 assert len(groups) == 1, "expected single group"
                 key = groups[0]
+                ordeleteline = False
+                if key.endswith(OR_DELETE_LINE):
+                    ordeleteline = True
+                    key = key[:-len(OR_DELETE_LINE)]
                 token = rules[key]
+                if ordeleteline and token is None:
+                    skip_row = True
+                    break
                 edits.append((match.span(), token))
+            if skip_row:
+                continue
             if edits:
                 # invert the spans
                 spans = [(None, 0)] + [x[0] for x in edits] + [(len(row), None)]
@@ -309,23 +321,25 @@ def main():
     parser.add_argument("--recipe", default="ray",
                         help="the SLURM recipe to use to generate scripts")
     parser.add_argument("--template_dir",
+                        type=Path,
                         help="if given, override directory containing SLURM templates")
-    parser.add_argument("--partition", default="gpu",
+    parser.add_argument("--partition", default=None,
                         help="The name of the SLURM partition used to run the job")
-    parser.add_argument("--time_limit", default="96:00:00",
+    parser.add_argument("--time_limit", default=None,
                         help="The maximum amount of time allowed to run the job")
     parser.add_argument("--gen_script_dir", default="data/slurm-gen-scripts",
+                        type=Path,
                         help="directory in which generated slurm scripts will be stored")
     parser.add_argument("--cmd", default='echo "hello"',
                         help="single command (or comma separated commands) to run")
-    parser.add_argument("--mem", default='60G',
+    parser.add_argument("--mem", default=None,
                         help="the memory to be requested for each SLURM worker")
     parser.add_argument("--prep", default="", help="a command to be run before srun")
     parser.add_argument("--job_array_size", type=int, default=2,
                         help="The number of SLURM array workers")
-    parser.add_argument("--cpus_per_task", type=int, default=5,
+    parser.add_argument("--cpus_per_task", type=int, default=None,
                         help="the number of cpus requested for each SLURM task")
-    parser.add_argument("--gpus_per_task", type=int, default=1,
+    parser.add_argument("--gpus_per_task", type=int, default=None,
                         help="the number of gpus requested for each SLURM task")
     parser.add_argument("--throttle_array", type=int, default=0,
                         help="limit the number of array workers running at once")
@@ -341,8 +355,7 @@ def main():
                         help="whether to watch the generated SLURM logs")
     parser.add_argument("--exclude", default="",
                         help="comma separated list of nodes to exclude")
-    parser.add_argument("--constraint_str", default="",
-                        help="SLURM --constraint string")
+    parser.add_argument("--constraint_str", help="SLURM --constraint string")
     parser.add_argument("--job_queue", default="",
                         help="a queue of jobs to pass to a yaspi recipe")
     parser.add_argument("--custom_directives", default="",
